#!/bin/sh

#The Pyra can compile on device without issues, This script is for compiling on device not cross-compiled

if [ $# -eq 0 ]
  then
    echo "No build target supplied, just a hint try: release "
    exit
fi

TARGET=armv7l-pyra

export TARGET
#<<COMMENT
#CFLAGS=" -mcpu=cortex-a15 -mfpu=neon -mfloat-abi=hard -I/opt/omap5-sgx-ddk-um-linux/include/ -L/usr/lib/arm-linux-gnueabihf/ -L/opt/omap5-sgx-ddk-um-linux/lib -lcrypto -ldl"
CFLAGS=" -mcpu=cortex-a15 -mfpu=neon -mfloat-abi=hard -funroll-loops -L/usr/lib/arm-linux-gnueabihf/ -L/opt/omap5-sgx-ddk-um-linux/lib -lcrypto -ldl"

export CFLAGS

#For some reason some configure scripts are pulled down from the SVN without execute permissions.
chmod -v +x */configure
chmod -v +x tools/moddesc/configure
echo "### Building 3rd party software ###"
cd 3rdparty/des-4.04b
case $1 in
    release)
        make clean && make -j4
        ;;

    *)
        make -j4
        ;;
esac
if [ $? -ne 0 ]; then
    echo "*** ABORT ***"
    exit 1
fi
cd -

echo "### Building BennuGD Core ###"

cd core
case $1 in
    release)
        ./configure && make clean && make -j4
        ;;

    *)
        make -j4
        ;;
esac
if [ $? -ne 0 ]; then
    echo "*** ABORT ***"
    exit 1
fi
cd -

echo "### Building BennuGD Modules ###"

cd modules
case $1 in
    release)
        ./configure && make clean && make -j4
        ;;

    *)
        make -j4
        ;;
esac
if [ $? -ne 0 ]; then
    echo "*** ABORT ***"
    exit 1
fi
cd -

echo "### Building BennuGD Tools ###"

cd tools/moddesc
case $1 in
    release)
        ./configure && make clean && make -j4
        ;;

    *)
        make -j4
        ;;
esac
if [ $? -ne 0 ]; then
    echo "*** ABORT ***"
    exit 1
fi
cd -

echo "### Copying files to bin folder ###"

mkdir -p bin/$TARGET 2>/dev/null
mkdir -p bin/$TARGET/lib 2>/dev/null
mkdir -p bin/$TARGET/bin 2>/dev/null
cp 3rdparty/des-4.04b/libdes.so bin/$TARGET/lib
cp core/bgdi/src/.libs/bgdi bin/$TARGET/bin
cp core/bgdc/src/bgdc bin/$TARGET/bin
cp core/bgdrtm/src/.libs/libbgdrtm.so bin/$TARGET/lib
cp $(find modules -name '*.so') bin/$TARGET/lib
cp tools/moddesc/moddesc bin/$TARGET/bin

#COMMENT

echo "### Build Pyra DBP package ###"

export DBP_TARGET_DIR="bin/"$TARGET"-dbp"
export DBP=$DBP_TARGET_DIR"/SoRR.dbp"
export DBP_TEMPLATE=dbp_include/default.desktop
export DBP_SCRIPT=dbp_include/SoRR
export DBP_ICON=dbp_include/streets_of_rage_remake.png

echo "Making DBP packaging directories"
mkdir -p $DBP_TARGET_DIR 2>/dev/null
mkdir -p $DBP_TARGET_DIR/icons 2>/dev/null
cp $DBP_ICON $DBP_TARGET_DIR/icons/
mkdir -p $DBP_TARGET_DIR/meta 2>/dev/null
cp $DBP_TEMPLATE $DBP_TARGET_DIR/meta
cp $DBP_SCRIPT bin/$TARGET
echo "Making DBP file from build target."
mksquashfs bin/$TARGET $DBP
cd $DBP_TARGET_DIR
echo "Building Meta Data and adding it to DBP"
zip -rv meta.zip meta/ icons/
cd ../../
cat $DBP_TARGET_DIR"/meta.zip" >> $DBP


echo "### Build done! ###"

exit 0

